@@ -1,11 +1,17 @@
 analyzeBits <-
-function(value,mode=1){
+function(value,mode=1, bitpos=0){
 	if (is.na(value)){
 		return(NA)
 	}
 	
+	if ((bitpos < 0)||(bitpos > 15)){
+		stop("bitpos has to be between 0 and 15")
+	}
+	
 	mask <- 0
 
+	if (mode == 0)
+		mask <- .C("getBits", number=as.integer(value), pos=as.integer(bitpos), m=as.integer(mask), PACKAGE="phenex")$lw;
 	if (mode == 1)
 		mask <- .C("getLandWater", number=as.integer(value), lw=as.integer(mask), PACKAGE="phenex")$lw;
 	if (mode == 2)
@@ -14,4 +20,4 @@ function(value,mode=1){
 		mask <- .C("getDayNo", number=as.integer(value), day=as.integer(mask), PACKAGE="phenex")$day;
 	
 	return(mask)
-}
\ No newline at end of file
+}
